closeSync method
void
closeSync()
Clear the used memory and close the underlying file handle.
Implementation
void closeSync() {
_content?.closeSync();
_rawContent?.closeSync();
_content = null;
}
Clear the used memory and close the underlying file handle.
void closeSync() {
_content?.closeSync();
_rawContent?.closeSync();
_content = null;
}