compression property
The type of compression to use when encoding an archive. If this is not set, the default compression type will be used. For a zip file, this is deflate compression. This value is set when decoding a zip to the method of compression the file was stored in the zip file. It does not indicate the current compression of the file's content, it is only used for how the file should be compressed when encoding a zip.
Implementation
CompressionType? compression;