open method
Open the file with the given mode, for either read or write.
Implementation
@override
bool open({FileAccess mode = FileAccess.read}) => false;
Open the file with the given mode, for either read or write.
@override
bool open({FileAccess mode = FileAccess.read}) => false;