LzmaDecoder class

LZMA compression decoder, used by XZDecoder

Constructors

LzmaDecoder()
Creates an LZMA decoder.

Properties

dictionaryCap int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state ↔ _LzmaState
getter/setter pair

Methods

decode(InputStream input, int uncompressedLength) Uint8List
decodeUncompressed(InputStream input, int uncompressedLength) Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset({int? positionBits, int? literalPositionBits, int? literalContextBits, bool resetDictionary = false}) → void
toString() String
A string representation of this object.
inherited
trimDictionary(int maxSize) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited