OutputMemoryStream class

Inheritance

Constructors

OutputMemoryStream({int? size = defaultBufferSize, ByteOrder byteOrder = ByteOrder.littleEndian})
Create a byte buffer for writing.

Properties

byteOrder ByteOrder
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isOpen bool
no setterinherited
length int
getter/setter pairoverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear the buffer.
override
close() Future<void>
inherited
closeSync() → void
inherited
flush() → void
Write any pending data writes to the output.
override
getBytes() Uint8List
Get the resulting bytes from the buffer.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() → void
inherited
reset() → void
Reset the buffer.
subset(int start, [int? end]) Uint8List
Return the subset of the buffer in the range start:end.
override
toString() String
A string representation of this object.
inherited
writeByte(int value) → void
Write a byte to the end of the buffer.
override
writeBytes(List<int> bytes, {int? length}) → void
Write a set of bytes to the end of the buffer.
override
writeStream(InputStream stream) → void
Write an InputStream to the output stream.
override
writeUint16(int value) → void
Write a 16-bit word to the output stream.
inherited
writeUint32(int value) → void
Write a 32-bit word to the end of the buffer.
inherited
writeUint64(int value) → void
Write a 64-bit word to the end of the buffer.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultBufferSize → const int