SHA1Digest class

Implementation of SHA-1 digest

Inheritance
Implemented types

Constructors

SHA1Digest()

Properties

buffer List<int>
finalinherited
bufferOffset int
getter/setter pairinherited
byteLength int
no setteroverride
digestSize int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state List<int>
finalinherited

Methods

doFinal(Uint8List out, int outOff) int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(Uint8List data) Uint8List
inherited
processBlock() → void
override
reset() → void
inherited
resetState() → void
override
toString() String
A string representation of this object.
inherited
update(Uint8List inp, int inpOff, int len) → void
inherited
updateByte(int inp) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited