ZLibDecoderWeb class

Constructors

ZLibDecoderWeb()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeBytes(List<int> data, {bool verify = false, bool raw = false}) → Uint8List
decodeStream(InputStream input, OutputStream output, {bool verify = false, bool raw = false}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited