ZipDecoder class

Decode a zip formatted buffer into an Archive object.

Constructors

ZipDecoder()

Properties

directory ↔ ZipDirectory
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeBytes(List<int> bytes, {bool verify = false, String? password, ArchiveCallback? callback}) → Archive
decodeStream(InputStream input, {bool verify = false, String? password, ArchiveCallback? callback}) → Archive
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited