ZipDirectory class

The internal directory structure for a zip archive, used by ZipDecoder.

Constructors

ZipDirectory()

Properties

centralDirectoryOffset ↔ int
getter/setter pair
centralDirectorySize ↔ int
getter/setter pair
diskWithTheStartOfTheCentralDirectory ↔ int
getter/setter pair
fileHeaders → List<ZipFileHeader>
final
filePosition ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numberOfThisDisk ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCentralDirectoryEntries ↔ int
getter/setter pair
totalCentralDirectoryEntriesOnThisDisk ↔ int
getter/setter pair
zipFileComment ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(InputStream input, {String? password}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

eocdSignature → const int
eocdSize → const int
zip64EocdLocatorSignature → const int
zip64EocdLocatorSize → const int
zip64EocdSignature → const int
zip64EocdSize → const int