OutputFileStream class
- Inheritance
-
- Object
- OutputStream
- OutputFileStream
Constructors
- OutputFileStream(String path, {ByteOrder byteOrder = ByteOrder.littleEndian, int? bufferSize})
-
factory
- OutputFileStream.toRamFile(RamFileHandle ramFileHandle, {ByteOrder byteOrder = ByteOrder.littleEndian, int? bufferSize})
-
factory
- OutputFileStream.withFileHandle(AbstractFileHandle _fileHandle, {ByteOrder byteOrder = ByteOrder.littleEndian, int? bufferSize})
Properties
Methods
-
clear(
) → Future< void> -
override
-
close(
) → Future< void> -
override
-
closeSync(
) → void -
override
-
flush(
) → void -
Write any pending data writes to the output.
override
-
getBytes(
) → Uint8List -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
) → void -
inherited
-
subset(
int start, [int? end]) → Uint8List -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
writeBackReference(
int distance, int count) → void -
Append
countbytes copied fromdistancebytes before the current end of the stream (an LZ77 back-reference, as used by Inflate). Correctly handles overlapping copies wherecount>distance(e.g. RLE-style runs), reproducing the repeating pattern.inherited -
writeByte(
int value) → void -
Write a byte to the end of the buffer.
override
-
writeBytes(
List< int> bytes, {int? length}) → void -
Write a set of bytes to the end of the buffer.
override
-
writeStream(
InputStream stream) → void -
Write an InputStream to the output stream.
override
-
writeUint16(
int value) → void -
Write a 16-bit word to the end of the buffer.
override
-
writeUint32(
int value) → void -
Write a 32-bit word to the end of the buffer.
override
-
writeUint64(
int value) → void -
Write a 64-bit word to the end of the buffer.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kDefaultBufferSize → const int